package
Version:
v0.10.0
Opens a new window with list of versions in this module.
Published: Apr 6, 2026
License: MIT
Opens a new window with license information.
Imports: 13
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Run is the top-level sync orchestration entry point.
type Options struct {
Force bool
TargetDir string
}
Options controls sync behavior.
State represents the detected installation state of the agentic kernel.
const (
StateAbsent State = iota
StateAgentsMDOnly
StateAgenticOnly
StateBoth
)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.